==> fremix-1.0.0.tgz: package/libs/js/gulp/tasks/javascript.js <==
// Fremix Gulp Javascript Tasks

var gulp = require("gulp"),
    uglify = require("gulp-uglify"),
    concat = require("gulp-concat"),
    rename = require("gulp-rename");

var LIBS = [
    'bower_components/jquery/dist/jquery.js',
    'bower_components/fastclick/lib/fastclick.js',
    'bower_components/viewport-units-buggyfill/viewport-units-buggyfill.js',
    'bower_components/tether/tether.js',
    'bower_components/angular/angular.js',
    'bower_components/angular-highlightjs/angular-highlightjs.js',
    'bower_components/angular-animate/angular-animate.js',
    'bower_components/angular-ui-router/release/angular-ui-router.js',
    'bower_components/hammerjs/hammer.js'
];

var FOUNDATION = [
    'bower_components/foundation-apps/js/vendor/**/*.js',
    'bower_components/foundation-apps/js/angular/**/*.js',
    '!bower_components/foundation-apps/js/angular/foundation.js',
    '!bower_components/foundation-apps/js/angular/app.js',
    'docs/assets/js/foundation.templates.js'
  //  'docs/assets/js/highlight.pack.js'
];

var FREMIX = [
    'libs/js/angular/fremix.js'
];

var DOCS = [
    'docs/assets/js/routes.js',
    'docs/assets/js/app.js'
];

gulp.task('javascript', ['javascript:fremix', 'javascript:docs']);

gulp.task('javascript:fremix',['copy:html2js'], function () {
    var dirs = LIBS.concat(
        FOUNDATION,
        FREMIX
    );
    return gulp.src(dirs)
        .pipe(concat('fremix.js'))
        .pipe(gulp.dest('./dist/js/'))
        .pipe(uglify({
            beautify: true,
            mangle: false
        }))
        .pipe(rename('fremix.min.js'))
        .pipe(gulp.dest('./dist/js/'));
});

gulp.task('javascript:docs', ['copy:pages', 'copy:html2js'],function () {
    var dirs = LIBS.concat(
        FOUNDATION,
        FREMIX,
        DOCS
    );
    return gulp.src(dirs)
        .pipe(uglify({
            beautify: true,
            mangle: false
        }))
        .pipe(concat('app.js'))
        .pipe(gulp.dest('./build/assets/js/'))
});

==> fremix-1.2.0.tgz: package/libs/js/gulp/tasks/javascript.js <==
// Fremix Gulp Javascript Tasks

var gulp = require("gulp"),
    uglify = require("gulp-uglify"),
    concat = require("gulp-concat"),
    rename = require("gulp-rename");

var LIBS = [
    'bower_components/jquery/dist/jquery.js',
    'bower_components/fastclick/lib/fastclick.js',
    'bower_components/viewport-units-buggyfill/viewport-units-buggyfill.js',
    'bower_components/tether/tether.js',
    'bower_components/hammerjs/hammer.js'
];

var ANGULAR = [
    'bower_components/angular/angular.js',
    'bower_components/angular-animate/angular-animate.js',
    'bower_components/angular-ui-router/release/angular-ui-router.js',
    'bower_components/angular-highlightjs/angular-highlightjs.js'
];

var FOUNDATION = [
    'bower_components/foundation-apps/js/vendor/**/*.js',
    'bower_components/foundation-apps/js/angular/**/*.js',
    '!bower_components/foundation-apps/js/angular/foundation.js',
    '!bower_components/foundation-apps/js/angular/app.js',
    'docs/assets/js/foundation.templates.js',
    'libs/js/angular/foundation.js'
  //  'docs/assets/js/highlight.pack.js'
];

var FREMIX = [
    'libs/js/angular/fremix.js'
];

var DOCS = [
    'docs/assets/js/routes.js',
    'docs/assets/js/app.js'
];

gulp.task('javascript', ['javascript:fremix', 'javascript:docs']);

gulp.task('javascript:fremix',['copy:html2js'], function () {
    var dirs = LIBS.concat(
        ANGULAR,
        FOUNDATION,
        FREMIX
    );
    return gulp.src(dirs)
        .pipe(concat('fremix.js'))
        .pipe(gulp.dest('./dist/js/'))
        .pipe(uglify({
            beautify: true,
            mangle: false
        }))
        .pipe(rename('fremix.min.js'))
        .pipe(gulp.dest('./dist/js/'));
});

gulp.task('javascript:docs', ['copy:pages', 'copy:html2js'],function () {
    var dirs = LIBS.concat(
        ANGULAR,
        FOUNDATION,
        FREMIX,
        DOCS
    );
    return gulp.src(dirs)
        .pipe(uglify({
            beautify: true,
            mangle: false
        }))
        .pipe(concat('app.js'))
        .pipe(gulp.dest('./build/assets/js/'))
});
